@@ -1389,7 +1389,8 @@ static double treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeo
 
 
 //		if( fftlog[m1] && fftlog[m2] ) ffttry = ( nlen[m1] > clus1 && nlen[m2] > clus2 );
-		if( fftlog[m1] && fftlog[m2] ) ffttry = ( nlen[m1] > clus1 && nlen[m2] > clus2 && clus1 < 1000 && clus2 < 1000 );
+//		if( fftlog[m1] && fftlog[m2] ) ffttry = ( nlen[m1] > clus1 && nlen[m2] > clus2 && clus1 < 1000 && clus2 < 1000 );
+		if( fftlog[m1] && fftlog[m2] ) ffttry = ( nlen[m1] > clus1 && nlen[m2] > clus2 );
 		else						   ffttry = 0;
 //		ffttry = ( nlen[m1] > clus1 && nlen[m2] > clus2 && clus1 < 5000 && clus2 < 5000 ); // v6.708
 //		fprintf( stderr, "f=%d, len1/fftlog[m1]=%f, clus1=%d, len2/fftlog[m2]=%f, clus2=%d\n", ffttry, (double)len1/fftlog[m1], clus1, (double)len2/fftlog[m2], clus2 );
@@ -2961,7 +2962,7 @@ int main( int argc, char *argv[] )
 	fprintf( stderr, "norg = %d\n", norg );
 	fprintf( stderr, "njobc = %d\n", njobc );
 //	if( norg > 1000 || nadd > 1000 ) use_fft = 0;
-	if( norg > 1000 ) use_fft = 0;
+//	if( norg > 1000 ) use_fft = 0;
 
 
 	fullseqlen = alloclen = nlenmax*4+1; //chuui!
