@@ -1,7 +1,6 @@
 #define USE_XCED 0
 
-#define _SVID_SOURCE
-#define _BSD_SOURCE
+#define _XOPEN_SOURCE
 
 #if USE_XCED
 #include "config.h"
@@ -37,7 +36,7 @@
 
 
 
-#define VERSION "7.464"
+#define VERSION "7.467"
 #define SHOWVERSION reporterr( "%s (%s) Version " VERSION "\nalg=%c, model=%s, amax=%3.1f\n%d thread(s)\n\n", progName( argv[0] ), (dorp=='d')?"nuc":((nblosum==-2)?"text":"aa"), alg, modelname, specificityconsideration, nthread )
 
 #define FFT_THRESHOLD  80
